from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.files import Files

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.upload_url import UploadUrl

from box_sdk_gen.schemas.conflict_error import ConflictError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.networking.fetch_options import MultipartItem

from box_sdk_gen.serialization.json import SerializedData


class UploadFileVersionAttributes(BaseObject):
    def __init__(
        self, name: str, *, content_modified_at: Optional[DateTime] = None, **kwargs
    ):
        """
                :param name: An optional new name for the file. If specified, the file
        will be renamed when the new version is uploaded.
                :type name: str
                :param content_modified_at: Defines the time the file was last modified at.

        If not set, the upload time will be used., defaults to None
                :type content_modified_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.name = name
        self.content_modified_at = content_modified_at


class PreflightFileUploadCheckParent(BaseObject):
    def __init__(self, *, id: Optional[str] = None, **kwargs):
        """
        :param id: The ID of parent item., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id


class UploadFileAttributesParentField(BaseObject):
    def __init__(self, id: str, **kwargs):
        """
                :param id: The id of the parent folder. Use
        `0` for the user's root folder.
                :type id: str
        """
        super().__init__(**kwargs)
        self.id = id


class UploadFileAttributes(BaseObject):
    def __init__(
        self,
        name: str,
        parent: UploadFileAttributesParentField,
        *,
        content_created_at: Optional[DateTime] = None,
        content_modified_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
                :param name: The name of the file.

        File names must be unique within their parent folder. The name check is case-insensitive, so a file
        named `New File` cannot be created in a parent folder that already contains a folder named `new file`.
                :type name: str
                :param parent: The parent folder to upload the file to.
                :type parent: UploadFileAttributesParentField
                :param content_created_at: Defines the time the file was originally created at.

        If not set, the upload time will be used., defaults to None
                :type content_created_at: Optional[DateTime], optional
                :param content_modified_at: Defines the time the file was last modified at.

        If not set, the upload time will be used., defaults to None
                :type content_modified_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.name = name
        self.parent = parent
        self.content_created_at = content_created_at
        self.content_modified_at = content_modified_at


class UploadWithPreflightCheckAttributesParentField(BaseObject):
    def __init__(self, id: str, **kwargs):
        """
                :param id: The id of the parent folder. Use
        `0` for the user's root folder.
                :type id: str
        """
        super().__init__(**kwargs)
        self.id = id


class UploadWithPreflightCheckAttributes(BaseObject):
    def __init__(
        self,
        name: str,
        parent: UploadWithPreflightCheckAttributesParentField,
        size: int,
        *,
        content_created_at: Optional[DateTime] = None,
        content_modified_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
                :param name: The name of the file.

        File names must be unique within their parent folder. The name check is case-insensitive, so a file
        named `New File` cannot be created in a parent folder that already contains a folder named `new file`.
                :type name: str
                :param parent: The parent folder to upload the file to.
                :type parent: UploadWithPreflightCheckAttributesParentField
                :param size: The size of the file in bytes
                :type size: int
                :param content_created_at: Defines the time the file was originally created at.

        If not set, the upload time will be used., defaults to None
                :type content_created_at: Optional[DateTime], optional
                :param content_modified_at: Defines the time the file was last modified at.

        If not set, the upload time will be used., defaults to None
                :type content_modified_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.name = name
        self.parent = parent
        self.size = size
        self.content_created_at = content_created_at
        self.content_modified_at = content_modified_at


class UploadsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def upload_file_version(
        self,
        file_id: str,
        attributes: UploadFileVersionAttributes,
        file: ByteStream,
        *,
        file_file_name: Optional[str] = None,
        file_content_type: Optional[str] = None,
        fields: Optional[List[str]] = None,
        if_match: Optional[str] = None,
        content_md_5: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Files:
        """
                Update a file's content. For file sizes over 50MB we recommend

                using the Chunk Upload APIs.


                The `attributes` part of the body must come **before** the


                `file` part. Requests that do not follow this format when


                uploading the file will receive a HTTP `400` error with a


                `metadata_after_file_contents` error code.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param attributes: The additional attributes of the file being uploaded. Mainly the
        name and the parent folder. These attributes are part of the multi
        part request body and are in JSON format.

        <Message warning>

          The `attributes` part of the body must come **before** the
          `file` part. Requests that do not follow this format when
          uploading the file will receive a HTTP `400` error with a
          `metadata_after_file_contents` error code.

        </Message>
                :type attributes: UploadFileVersionAttributes
                :param file: The content of the file to upload to Box.

        <Message warning>

          The `attributes` part of the body must come **before** the
          `file` part. Requests that do not follow this format when
          uploading the file will receive a HTTP `400` error with a
          `metadata_after_file_contents` error code.

        </Message>
                :type file: ByteStream
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param if_match: Ensures this item hasn't recently changed before
        making changes.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `412 Precondition Failed` if it
        has changed since., defaults to None
                :type if_match: Optional[str], optional
                :param content_md_5: An optional header containing the SHA1 hash of the file to
        ensure that the file was not corrupted in transit., defaults to None
                :type content_md_5: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'attributes': attributes,
            'file': file,
            'file_file_name': file_file_name,
            'file_content_type': file_content_type,
        }
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params(
            {
                'if-match': to_string(if_match),
                'content-md5': to_string(content_md_5),
                **extra_headers,
            }
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.upload_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/content',
                    ]
                ),
                method='POST',
                params=query_params_map,
                headers=headers_map,
                multipart_data=[
                    MultipartItem(part_name='attributes', data=serialize(attributes)),
                    MultipartItem(
                        part_name='file',
                        file_stream=file,
                        file_name=file_file_name,
                        content_type=file_content_type,
                    ),
                ],
                content_type='multipart/form-data',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Files)

    def preflight_file_upload_check(
        self,
        *,
        name: Optional[str] = None,
        size: Optional[int] = None,
        parent: Optional[PreflightFileUploadCheckParent] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> UploadUrl:
        """
        Performs a check to verify that a file will be accepted by Box

        before you upload the entire file.

        :param name: The name for the file., defaults to None
        :type name: Optional[str], optional
        :param size: The size of the file in bytes., defaults to None
        :type size: Optional[int], optional
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'name': name, 'size': size, 'parent': parent}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/files/content']
                ),
                method='OPTIONS',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, UploadUrl)

    def upload_file(
        self,
        attributes: UploadFileAttributes,
        file: ByteStream,
        *,
        file_file_name: Optional[str] = None,
        file_content_type: Optional[str] = None,
        fields: Optional[List[str]] = None,
        content_md_5: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Files:
        """
                Uploads a small file to Box. For file sizes over 50MB we recommend

                using the Chunk Upload APIs.


                The `attributes` part of the body must come **before** the


                `file` part. Requests that do not follow this format when


                uploading the file will receive a HTTP `400` error with a


                `metadata_after_file_contents` error code.

                :param attributes: The additional attributes of the file being uploaded. Mainly the
        name and the parent folder. These attributes are part of the multi
        part request body and are in JSON format.

        <Message warning>

          The `attributes` part of the body must come **before** the
          `file` part. Requests that do not follow this format when
          uploading the file will receive a HTTP `400` error with a
          `metadata_after_file_contents` error code.

        </Message>
                :type attributes: UploadFileAttributes
                :param file: The content of the file to upload to Box.

        <Message warning>

          The `attributes` part of the body must come **before** the
          `file` part. Requests that do not follow this format when
          uploading the file will receive a HTTP `400` error with a
          `metadata_after_file_contents` error code.

        </Message>
                :type file: ByteStream
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param content_md_5: An optional header containing the SHA1 hash of the file to
        ensure that the file was not corrupted in transit., defaults to None
                :type content_md_5: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'attributes': attributes,
            'file': file,
            'file_file_name': file_file_name,
            'file_content_type': file_content_type,
        }
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params(
            {'content-md5': to_string(content_md_5), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.upload_url, '/2.0/files/content']
                ),
                method='POST',
                params=query_params_map,
                headers=headers_map,
                multipart_data=[
                    MultipartItem(part_name='attributes', data=serialize(attributes)),
                    MultipartItem(
                        part_name='file',
                        file_stream=file,
                        file_name=file_file_name,
                        content_type=file_content_type,
                    ),
                ],
                content_type='multipart/form-data',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Files)

    def upload_with_preflight_check(
        self,
        attributes: UploadWithPreflightCheckAttributes,
        file: ByteStream,
        *,
        file_file_name: Optional[str] = None,
        file_content_type: Optional[str] = None,
        fields: Optional[List[str]] = None,
        content_md_5: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Files:
        """
                 Upload a file with a preflight check
                :param file: The content of the file to upload to Box.

        <Message warning>

          The `attributes` part of the body must come **before** the
          `file` part. Requests that do not follow this format when
          uploading the file will receive a HTTP `400` error with a
          `metadata_after_file_contents` error code.

        </Message>
                :type file: ByteStream
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param content_md_5: An optional header containing the SHA1 hash of the file to
        ensure that the file was not corrupted in transit., defaults to None
                :type content_md_5: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'attributes': attributes,
            'file': file,
            'file_file_name': file_file_name,
            'file_content_type': file_content_type,
        }
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params(
            {'content-md5': to_string(content_md_5), **extra_headers}
        )
        preflight_upload_url: UploadUrl = self.preflight_file_upload_check(
            name=attributes.name,
            size=attributes.size,
            parent=PreflightFileUploadCheckParent(id=attributes.parent.id),
            extra_headers=extra_headers,
        )
        if (
            preflight_upload_url.upload_url == None
            or not 'http' in preflight_upload_url.upload_url
        ):
            raise BoxSDKError(message='Unable to get preflight upload URL')
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=preflight_upload_url.upload_url,
                method='POST',
                params=query_params_map,
                headers=headers_map,
                multipart_data=[
                    MultipartItem(part_name='attributes', data=serialize(attributes)),
                    MultipartItem(
                        part_name='file',
                        file_stream=file,
                        file_name=file_file_name,
                        content_type=file_content_type,
                    ),
                ],
                content_type='multipart/form-data',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Files)



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class AiLlmEndpointParamsOpenAiTypeField(str, Enum):
    OPENAI_PARAMS = 'openai_params'


class AiLlmEndpointParamsOpenAi(BaseObject):
    _discriminator = 'type', {'openai_params'}

    def __init__(
        self,
        *,
        type: AiLlmEndpointParamsOpenAiTypeField = AiLlmEndpointParamsOpenAiTypeField.OPENAI_PARAMS,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        frequency_penalty: Optional[float] = None,
        presence_penalty: Optional[float] = None,
        stop: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The type of the AI LLM endpoint params object for OpenAI.
        This parameter is **required**., defaults to AiLlmEndpointParamsOpenAiTypeField.OPENAI_PARAMS
                :type type: AiLlmEndpointParamsOpenAiTypeField, optional
                :param temperature: What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random,
        while lower values like 0.2 will make it more focused and deterministic.
        We generally recommend altering this or `top_p` but not both., defaults to None
                :type temperature: Optional[float], optional
                :param top_p: An alternative to sampling with temperature, called nucleus sampling, where the model considers the results
        of the tokens with `top_p` probability mass. So 0.1 means only the tokens comprising the top 10% probability
        mass are considered. We generally recommend altering this or temperature but not both., defaults to None
                :type top_p: Optional[float], optional
                :param frequency_penalty: A number between -2.0 and 2.0. Positive values penalize new tokens based on their existing frequency in the
        text so far, decreasing the model's likelihood to repeat the same line verbatim., defaults to None
                :type frequency_penalty: Optional[float], optional
                :param presence_penalty: A number between -2.0 and 2.0. Positive values penalize new tokens based on whether they appear in the text so far, increasing the model's likelihood to talk about new topics., defaults to None
                :type presence_penalty: Optional[float], optional
                :param stop: Up to 4 sequences where the API will stop generating further tokens., defaults to None
                :type stop: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.temperature = temperature
        self.top_p = top_p
        self.frequency_penalty = frequency_penalty
        self.presence_penalty = presence_penalty
        self.stop = stop



from abc import abstractmethod

from typing import Optional

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import random


class RetryStrategy:
    def __init__(self):
        pass

    @abstractmethod
    def should_retry(
        self,
        fetch_options: FetchOptions,
        fetch_response: FetchResponse,
        attempt_number: int,
    ) -> bool:
        pass

    @abstractmethod
    def retry_after(
        self,
        fetch_options: FetchOptions,
        fetch_response: FetchResponse,
        attempt_number: int,
    ) -> float:
        pass


class BoxRetryStrategy(RetryStrategy):
    def __init__(
        self,
        *,
        max_attempts: int = 5,
        retry_randomization_factor: float = 0.5,
        retry_base_interval: float = 1,
        max_retries_on_exception: int = 2,
        **kwargs
    ):
        super().__init__(**kwargs)
        self.max_attempts = max_attempts
        self.retry_randomization_factor = retry_randomization_factor
        self.retry_base_interval = retry_base_interval
        self.max_retries_on_exception = max_retries_on_exception

    def should_retry(
        self,
        fetch_options: FetchOptions,
        fetch_response: FetchResponse,
        attempt_number: int,
    ) -> bool:
        if fetch_response.status == 0:
            return attempt_number <= self.max_retries_on_exception
        is_successful: bool = (
            fetch_response.status >= 200 and fetch_response.status < 400
        )
        retry_after_header: Optional[str] = (
            fetch_response.headers.get('Retry-After')
            if 'Retry-After' in fetch_response.headers
            else None
        )
        is_accepted_with_retry_after: bool = (
            fetch_response.status == 202 and not retry_after_header == None
        )
        if attempt_number >= self.max_attempts:
            return False
        if is_accepted_with_retry_after:
            return True
        if fetch_response.status >= 500:
            return True
        if fetch_response.status == 429:
            return True
        if fetch_response.status == 401 and not fetch_options.auth == None:
            fetch_options.auth.refresh_token(
                network_session=fetch_options.network_session
            )
            return True
        if is_successful:
            return False
        return False

    def retry_after(
        self,
        fetch_options: FetchOptions,
        fetch_response: FetchResponse,
        attempt_number: int,
    ) -> float:
        retry_after_header: Optional[str] = (
            fetch_response.headers.get('Retry-After')
            if 'Retry-After' in fetch_response.headers
            else None
        )
        if not retry_after_header == None:
            return float(retry_after_header)
        randomization: float = random(
            1 - self.retry_randomization_factor, 1 + self.retry_randomization_factor
        )
        exponential: float = 2**attempt_number
        return (exponential * self.retry_base_interval) * randomization



from enum import Enum

from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.ai_studio_agent_long_text_tool_response import (
    AiStudioAgentLongTextToolResponse,
)

from box_sdk_gen.schemas.ai_studio_agent_basic_text_tool_response import (
    AiStudioAgentBasicTextToolResponse,
)

from box_sdk_gen.schemas.ai_studio_agent_spreadsheet_tool_response import (
    AiStudioAgentSpreadsheetToolResponse,
)

from box_sdk_gen.box.errors import BoxSDKError


class AiStudioAgentAskResponseTypeField(str, Enum):
    AI_AGENT_ASK = 'ai_agent_ask'


class AiStudioAgentAskResponse(BaseObject):
    _discriminator = 'type', {'ai_agent_ask'}

    def __init__(
        self,
        access_state: str,
        description: str,
        *,
        type: AiStudioAgentAskResponseTypeField = AiStudioAgentAskResponseTypeField.AI_AGENT_ASK,
        custom_instructions: Optional[str] = None,
        suggested_questions: Optional[List[str]] = None,
        long_text: Optional[AiStudioAgentLongTextToolResponse] = None,
        basic_text: Optional[AiStudioAgentBasicTextToolResponse] = None,
        basic_image: Optional[AiStudioAgentBasicTextToolResponse] = None,
        spreadsheet: Optional[AiStudioAgentSpreadsheetToolResponse] = None,
        long_text_multi: Optional[AiStudioAgentLongTextToolResponse] = None,
        basic_text_multi: Optional[AiStudioAgentBasicTextToolResponse] = None,
        basic_image_multi: Optional[AiStudioAgentBasicTextToolResponse] = None,
        **kwargs
    ):
        """
        :param access_state: The state of the AI Agent capability. Possible values are: `enabled` and `disabled`.
        :type access_state: str
        :param description: The description of the AI agent.
        :type description: str
        :param type: The type of AI agent used to ask questions., defaults to AiStudioAgentAskResponseTypeField.AI_AGENT_ASK
        :type type: AiStudioAgentAskResponseTypeField, optional
        :param custom_instructions: Custom instructions for the AI agent., defaults to None
        :type custom_instructions: Optional[str], optional
        :param suggested_questions: Suggested questions for the AI agent. If null, suggested question will be generated. If empty, no suggested questions will be displayed., defaults to None
        :type suggested_questions: Optional[List[str]], optional
        """
        super().__init__(**kwargs)
        self.access_state = access_state
        self.description = description
        self.type = type
        self.custom_instructions = custom_instructions
        self.suggested_questions = suggested_questions
        self.long_text = long_text
        self.basic_text = basic_text
        self.basic_image = basic_image
        self.spreadsheet = spreadsheet
        self.long_text_multi = long_text_multi
        self.basic_text_multi = basic_text_multi
        self.basic_image_multi = basic_image_multi



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.upload_part import UploadPart

from box_sdk_gen.box.errors import BoxSDKError


class UploadedPart(BaseObject):
    def __init__(self, *, part: Optional[UploadPart] = None, **kwargs):
        super().__init__(**kwargs)
        self.part = part



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class GroupBaseV2025R0TypeField(str, Enum):
    GROUP = 'group'


class GroupBaseV2025R0(BaseObject):
    _discriminator = 'type', {'group'}

    def __init__(
        self,
        id: str,
        *,
        type: GroupBaseV2025R0TypeField = GroupBaseV2025R0TypeField.GROUP,
        **kwargs
    ):
        """
        :param id: The unique identifier for this object.
        :type id: str
        :param type: The value will always be `group`., defaults to GroupBaseV2025R0TypeField.GROUP
        :type type: GroupBaseV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from enum import Enum

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.internal.null_value import NullValue

from typing import Union

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.file_full import FileFull

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.internal.utils import DateTime


class UpdateFileByIdParent(BaseObject):
    def __init__(
        self, *, id: Optional[str] = None, user_id: Optional[str] = None, **kwargs
    ):
        """
        :param id: The ID of parent item., defaults to None
        :type id: Optional[str], optional
        :param user_id: The input for `user_id` is optional. Moving to non-root folder is not allowed when `user_id` is present. Parent folder id should be zero when `user_id` is provided., defaults to None
        :type user_id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.user_id = user_id


class UpdateFileByIdSharedLinkAccessField(str, Enum):
    OPEN = 'open'
    COMPANY = 'company'
    COLLABORATORS = 'collaborators'


class UpdateFileByIdSharedLinkPermissionsField(BaseObject):
    def __init__(self, *, can_download: Optional[bool] = None, **kwargs):
        """
                :param can_download: If the shared link allows for downloading of files.
        This can only be set when `access` is set to
        `open` or `company`., defaults to None
                :type can_download: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.can_download = can_download


class UpdateFileByIdSharedLink(BaseObject):
    def __init__(
        self,
        *,
        access: Optional[UpdateFileByIdSharedLinkAccessField] = None,
        password: Optional[str] = None,
        vanity_name: Optional[str] = None,
        unshared_at: Optional[DateTime] = None,
        permissions: Optional[UpdateFileByIdSharedLinkPermissionsField] = None,
        **kwargs
    ):
        """
                :param access: The level of access for the shared link. This can be
        restricted to anyone with the link (`open`), only people
        within the company (`company`) and only those who
        have been invited to the folder (`collaborators`).

        If not set, this field defaults to the access level specified
        by the enterprise admin. To create a shared link with this
        default setting pass the `shared_link` object with
        no `access` field, for example `{ "shared_link": {} }`.

        The `company` access level is only available to paid
        accounts., defaults to None
                :type access: Optional[UpdateFileByIdSharedLinkAccessField], optional
                :param password: The password required to access the shared link. Set the
        password to `null` to remove it.
        Passwords must now be at least eight characters
        long and include a number, upper case letter, or
        a non-numeric or non-alphabetic character.
        A password can only be set when `access` is set to `open`., defaults to None
                :type password: Optional[str], optional
                :param vanity_name: Defines a custom vanity name to use in the shared link URL,
        for example `https://app.box.com/v/my-shared-link`.

        Custom URLs should not be used when sharing sensitive content
        as vanity URLs are a lot easier to guess than regular shared links., defaults to None
                :type vanity_name: Optional[str], optional
                :param unshared_at: The timestamp at which this shared link will
        expire. This field can only be set by
        users with paid accounts., defaults to None
                :type unshared_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.access = access
        self.password = password
        self.vanity_name = vanity_name
        self.unshared_at = unshared_at
        self.permissions = permissions


class UpdateFileByIdLockAccessField(str, Enum):
    LOCK = 'lock'


class UpdateFileByIdLock(BaseObject):
    def __init__(
        self,
        *,
        access: Optional[UpdateFileByIdLockAccessField] = None,
        expires_at: Optional[DateTime] = None,
        is_download_prevented: Optional[bool] = None,
        **kwargs
    ):
        """
        :param access: The type of this object., defaults to None
        :type access: Optional[UpdateFileByIdLockAccessField], optional
        :param expires_at: Defines the time at which the lock expires., defaults to None
        :type expires_at: Optional[DateTime], optional
        :param is_download_prevented: Defines if the file can be downloaded while it is locked., defaults to None
        :type is_download_prevented: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.access = access
        self.expires_at = expires_at
        self.is_download_prevented = is_download_prevented


class UpdateFileByIdPermissionsCanDownloadField(str, Enum):
    OPEN = 'open'
    COMPANY = 'company'


class UpdateFileByIdPermissions(BaseObject):
    def __init__(
        self,
        *,
        can_download: Optional[UpdateFileByIdPermissionsCanDownloadField] = None,
        **kwargs
    ):
        """
                :param can_download: Defines who is allowed to download this file. The possible
        values are either `open` for everyone or `company` for
        the other members of the user's enterprise.

        This setting overrides the download permissions that are
        normally part of the `role` of a collaboration. When set to
        `company`, this essentially removes the download option for
        external users with `viewer` or `editor` a roles., defaults to None
                :type can_download: Optional[UpdateFileByIdPermissionsCanDownloadField], optional
        """
        super().__init__(**kwargs)
        self.can_download = can_download


class UpdateFileByIdCollections(BaseObject):
    def __init__(
        self, *, id: Optional[str] = None, type: Optional[str] = None, **kwargs
    ):
        """
        :param id: The unique identifier for this object., defaults to None
        :type id: Optional[str], optional
        :param type: The type for this object., defaults to None
        :type type: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class CopyFileParent(BaseObject):
    def __init__(self, id: str, **kwargs):
        """
        :param id: The ID of folder to copy the file to.
        :type id: str
        """
        super().__init__(**kwargs)
        self.id = id


class GetFileThumbnailUrlExtension(str, Enum):
    PNG = 'png'
    JPG = 'jpg'


class GetFileThumbnailByIdExtension(str, Enum):
    PNG = 'png'
    JPG = 'jpg'


class FilesManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_file_by_id(
        self,
        file_id: str,
        *,
        fields: Optional[List[str]] = None,
        if_none_match: Optional[str] = None,
        boxapi: Optional[str] = None,
        x_rep_hints: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileFull:
        """
                Retrieves the details about a file.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested.

        Additionally this field can be used to query any metadata
        applied to the file by specifying the `metadata` field as well
        as the scope and key of the template to retrieve, for example
        `?fields=metadata.enterprise_12345.contractTemplate`., defaults to None
                :type fields: Optional[List[str]], optional
                :param if_none_match: Ensures an item is only returned if it has changed.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `304 Not Modified` if the item has not
        changed since., defaults to None
                :type if_none_match: Optional[str], optional
                :param boxapi: The URL, and optional password, for the shared link of this item.

        This header can be used to access items that have not been
        explicitly shared with a user.

        Use the format `shared_link=[link]` or if a password is required then
        use `shared_link=[link]&shared_link_password=[password]`.

        This header can be used on the file or folder shared, as well as on any files
        or folders nested within the item., defaults to None
                :type boxapi: Optional[str], optional
                :param x_rep_hints: A header required to request specific `representations`
        of a file. Use this in combination with the `fields` query
        parameter to request a specific file representation.

        The general format for these representations is
        `X-Rep-Hints: [...]` where `[...]` is one or many
        hints in the format `[fileType?query]`.

        For example, to request a `png` representation in `32x32`
        as well as `64x64` pixel dimensions provide the following
        hints.

        `x-rep-hints: [jpg?dimensions=32x32][jpg?dimensions=64x64]`

        Additionally, a `text` representation is available for all
        document file types in Box using the `[extracted_text]`
        representation.

        `x-rep-hints: [extracted_text]`., defaults to None
                :type x_rep_hints: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params(
            {
                'if-none-match': to_string(if_none_match),
                'boxapi': to_string(boxapi),
                'x-rep-hints': to_string(x_rep_hints),
                **extra_headers,
            }
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileFull)

    def update_file_by_id(
        self,
        file_id: str,
        *,
        name: Optional[str] = None,
        description: Optional[str] = None,
        parent: Optional[UpdateFileByIdParent] = None,
        shared_link: Union[Optional[UpdateFileByIdSharedLink], NullValue] = None,
        lock: Union[Optional[UpdateFileByIdLock], NullValue] = None,
        disposition_at: Optional[DateTime] = None,
        permissions: Optional[UpdateFileByIdPermissions] = None,
        collections: Union[Optional[List[UpdateFileByIdCollections]], NullValue] = None,
        tags: Optional[List[str]] = None,
        fields: Optional[List[str]] = None,
        if_match: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileFull:
        """
                Updates a file. This can be used to rename or move a file,

                create a shared link, or lock a file.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param name: An optional different name for the file. This can be used to
        rename the file.

        File names must be unique within their parent folder. The name check is case-insensitive, so a file
        named `New File` cannot be created in a parent folder that already contains a folder named `new file`., defaults to None
                :type name: Optional[str], optional
                :param description: The description for a file. This can be seen in the right-hand sidebar panel
        when viewing a file in the Box web app. Additionally, this index is used in
        the search index of the file, allowing users to find the file by the content
        in the description., defaults to None
                :type description: Optional[str], optional
                :param lock: Defines a lock on an item. This prevents the item from being
        moved, renamed, or otherwise changed by anyone other than the user
        who created the lock.

        Set this to `null` to remove the lock., defaults to None
                :type lock: Union[Optional[UpdateFileByIdLock], NullValue], optional
                :param disposition_at: The retention expiration timestamp for the given file. This
        date cannot be shortened once set on a file., defaults to None
                :type disposition_at: Optional[DateTime], optional
                :param permissions: Defines who can download a file., defaults to None
                :type permissions: Optional[UpdateFileByIdPermissions], optional
                :param collections: An array of collections to make this file
        a member of. Currently
        we only support the `favorites` collection.

        To get the ID for a collection, use the
        [List all collections][1] endpoint.

        Passing an empty array `[]` or `null` will remove
        the file from all collections.

        [1]: https://developer.box.com/reference/get-collections, defaults to None
                :type collections: Union[Optional[List[UpdateFileByIdCollections]], NullValue], optional
                :param tags: The tags for this item. These tags are shown in
        the Box web app and mobile apps next to an item.

        To add or remove a tag, retrieve the item's current tags,
        modify them, and then update this field.

        There is a limit of 100 tags per item, and 10,000
        unique tags per enterprise., defaults to None
                :type tags: Optional[List[str]], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param if_match: Ensures this item hasn't recently changed before
        making changes.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `412 Precondition Failed` if it
        has changed since., defaults to None
                :type if_match: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'name': name,
            'description': description,
            'parent': parent,
            'shared_link': shared_link,
            'lock': lock,
            'disposition_at': disposition_at,
            'permissions': permissions,
            'collections': collections,
            'tags': tags,
        }
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params(
            {'if-match': to_string(if_match), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                    ]
                ),
                method='PUT',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileFull)

    def delete_file_by_id(
        self,
        file_id: str,
        *,
        if_match: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a file, either permanently or by moving it to

                the trash.


                The enterprise settings determine whether the item will


                be permanently deleted from Box or moved to the trash.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param if_match: Ensures this item hasn't recently changed before
        making changes.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `412 Precondition Failed` if it
        has changed since., defaults to None
                :type if_match: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'if-match': to_string(if_match), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def copy_file(
        self,
        file_id: str,
        parent: CopyFileParent,
        *,
        name: Optional[str] = None,
        version: Optional[str] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileFull:
        r"""
                Creates a copy of a file.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param parent: The destination folder to copy the file to.
                :type parent: CopyFileParent
                :param name: An optional new name for the copied file.

        There are some restrictions to the file name. Names containing
        non-printable ASCII characters, forward and backward slashes
        (`/`, `\`), and protected names like `.` and `..` are
        automatically sanitized by removing the non-allowed
        characters., defaults to None
                :type name: Optional[str], optional
                :param version: An optional ID of the specific file version to copy., defaults to None
                :type version: Optional[str], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'name': name, 'version': version, 'parent': parent}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/copy',
                    ]
                ),
                method='POST',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileFull)

    def get_file_thumbnail_url(
        self,
        file_id: str,
        extension: GetFileThumbnailUrlExtension,
        *,
        min_height: Optional[int] = None,
        min_width: Optional[int] = None,
        max_height: Optional[int] = None,
        max_width: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> str:
        """
                Retrieves a thumbnail, or smaller image representation, of a file.

                Sizes of `32x32`,`64x64`, `128x128`, and `256x256` can be returned in


                the `.png` format and sizes of `32x32`, `160x160`, and `320x320`


                can be returned in the `.jpg` format.


                Thumbnails can be generated for the image and video file formats listed


                [found on our community site][1].


                [1]: https://community.box.com/t5/Migrating-and-Previewing-Content/File-Types-and-Fonts-Supported-in-Box-Content-Preview/ta-p/327

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param extension: The file format for the thumbnail.
        Example: "png"
                :type extension: GetFileThumbnailUrlExtension
                :param min_height: The minimum height of the thumbnail., defaults to None
                :type min_height: Optional[int], optional
                :param min_width: The minimum width of the thumbnail., defaults to None
                :type min_width: Optional[int], optional
                :param max_height: The maximum height of the thumbnail., defaults to None
                :type max_height: Optional[int], optional
                :param max_width: The maximum width of the thumbnail., defaults to None
                :type max_width: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'min_height': to_string(min_height),
                'min_width': to_string(min_width),
                'max_height': to_string(max_height),
                'max_width': to_string(max_width),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/thumbnail.',
                        to_string(extension),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
                follow_redirects=False,
            )
        )
        if 'location' in response.headers:
            return response.headers.get('location')
        if 'Location' in response.headers:
            return response.headers.get('Location')
        raise BoxSDKError(message='No location header in response')

    def get_file_thumbnail_by_id(
        self,
        file_id: str,
        extension: GetFileThumbnailByIdExtension,
        *,
        min_height: Optional[int] = None,
        min_width: Optional[int] = None,
        max_height: Optional[int] = None,
        max_width: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Optional[ByteStream]:
        """
                Retrieves a thumbnail, or smaller image representation, of a file.

                Sizes of `32x32`,`64x64`, `128x128`, and `256x256` can be returned in


                the `.png` format and sizes of `32x32`, `160x160`, and `320x320`


                can be returned in the `.jpg` format.


                Thumbnails can be generated for the image and video file formats listed


                [found on our community site][1].


                [1]: https://community.box.com/t5/Migrating-and-Previewing-Content/File-Types-and-Fonts-Supported-in-Box-Content-Preview/ta-p/327

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param extension: The file format for the thumbnail.
        Example: "png"
                :type extension: GetFileThumbnailByIdExtension
                :param min_height: The minimum height of the thumbnail., defaults to None
                :type min_height: Optional[int], optional
                :param min_width: The minimum width of the thumbnail., defaults to None
                :type min_width: Optional[int], optional
                :param max_height: The maximum height of the thumbnail., defaults to None
                :type max_height: Optional[int], optional
                :param max_width: The maximum width of the thumbnail., defaults to None
                :type max_width: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'min_height': to_string(min_height),
                'min_width': to_string(min_width),
                'max_height': to_string(max_height),
                'max_width': to_string(max_width),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/thumbnail.',
                        to_string(extension),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.BINARY,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        if to_string(response.status) == '202':
            return None
        return response.content



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.tasks import Tasks

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.task import Task

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.internal.utils import DateTime


class CreateTaskItemTypeField(str, Enum):
    FILE = 'file'


class CreateTaskItem(BaseObject):
    _discriminator = 'type', {'file'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[CreateTaskItemTypeField] = None,
        **kwargs
    ):
        """
        :param id: The ID of the file., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `file`., defaults to None
        :type type: Optional[CreateTaskItemTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class CreateTaskAction(str, Enum):
    REVIEW = 'review'
    COMPLETE = 'complete'


class CreateTaskCompletionRule(str, Enum):
    ALL_ASSIGNEES = 'all_assignees'
    ANY_ASSIGNEE = 'any_assignee'


class UpdateTaskByIdAction(str, Enum):
    REVIEW = 'review'
    COMPLETE = 'complete'


class UpdateTaskByIdCompletionRule(str, Enum):
    ALL_ASSIGNEES = 'all_assignees'
    ANY_ASSIGNEE = 'any_assignee'


class TasksManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_file_tasks(
        self, file_id: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Tasks:
        """
                Retrieves a list of all the tasks for a file. This

                endpoint does not support pagination.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/tasks',
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Tasks)

    def create_task(
        self,
        item: CreateTaskItem,
        *,
        action: Optional[CreateTaskAction] = None,
        message: Optional[str] = None,
        due_at: Optional[DateTime] = None,
        completion_rule: Optional[CreateTaskCompletionRule] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Task:
        """
                Creates a single task on a file. This task is not assigned to any user and

                will need to be assigned separately.

                :param item: The file to attach the task to.
                :type item: CreateTaskItem
                :param action: The action the task assignee will be prompted to do. Must be

        * `review` defines an approval task that can be approved or,
        rejected
        * `complete` defines a general task which can be completed., defaults to None
                :type action: Optional[CreateTaskAction], optional
                :param message: An optional message to include with the task., defaults to None
                :type message: Optional[str], optional
                :param due_at: Defines when the task is due. Defaults to `null` if not
        provided., defaults to None
                :type due_at: Optional[DateTime], optional
                :param completion_rule: Defines which assignees need to complete this task before the task
        is considered completed.

        * `all_assignees` (default) requires all assignees to review or
        approve the task in order for it to be considered completed.
        * `any_assignee` accepts any one assignee to review or
        approve the task in order for it to be considered completed., defaults to None
                :type completion_rule: Optional[CreateTaskCompletionRule], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'item': item,
            'action': action,
            'message': message,
            'due_at': due_at,
            'completion_rule': completion_rule,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/tasks']),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Task)

    def get_task_by_id(
        self, task_id: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Task:
        """
                Retrieves information about a specific task.
                :param task_id: The ID of the task.
        Example: "12345"
                :type task_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/tasks/',
                        to_string(task_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Task)

    def update_task_by_id(
        self,
        task_id: str,
        *,
        action: Optional[UpdateTaskByIdAction] = None,
        message: Optional[str] = None,
        due_at: Optional[DateTime] = None,
        completion_rule: Optional[UpdateTaskByIdCompletionRule] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Task:
        """
                Updates a task. This can be used to update a task's configuration, or to

                update its completion state.

                :param task_id: The ID of the task.
        Example: "12345"
                :type task_id: str
                :param action: The action the task assignee will be prompted to do. Must be

        * `review` defines an approval task that can be approved or
        rejected,
        * `complete` defines a general task which can be completed., defaults to None
                :type action: Optional[UpdateTaskByIdAction], optional
                :param message: The message included with the task., defaults to None
                :type message: Optional[str], optional
                :param due_at: When the task is due at., defaults to None
                :type due_at: Optional[DateTime], optional
                :param completion_rule: Defines which assignees need to complete this task before the task
        is considered completed.

        * `all_assignees` (default) requires all assignees to review or
        approve the task in order for it to be considered completed.
        * `any_assignee` accepts any one assignee to review or
        approve the task in order for it to be considered completed., defaults to None
                :type completion_rule: Optional[UpdateTaskByIdCompletionRule], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'action': action,
            'message': message,
            'due_at': due_at,
            'completion_rule': completion_rule,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/tasks/',
                        to_string(task_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Task)

    def delete_task_by_id(
        self, task_id: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Removes a task from a file.
                :param task_id: The ID of the task.
        Example: "12345"
                :type task_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/tasks/',
                        to_string(task_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class WebhookMiniTypeField(str, Enum):
    WEBHOOK = 'webhook'


class WebhookMiniTargetTypeField(str, Enum):
    FILE = 'file'
    FOLDER = 'folder'


class WebhookMiniTargetField(BaseObject):
    _discriminator = 'type', {'file', 'folder'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[WebhookMiniTargetTypeField] = None,
        **kwargs
    ):
        """
        :param id: The ID of the item to trigger a webhook., defaults to None
        :type id: Optional[str], optional
        :param type: The type of item to trigger a webhook., defaults to None
        :type type: Optional[WebhookMiniTargetTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class WebhookMini(BaseObject):
    _discriminator = 'type', {'webhook'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[WebhookMiniTypeField] = None,
        target: Optional[WebhookMiniTargetField] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this webhook., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `webhook`., defaults to None
        :type type: Optional[WebhookMiniTypeField], optional
        :param target: The item that will trigger the webhook., defaults to None
        :type target: Optional[WebhookMiniTargetField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.target = target



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file_full import FileFull

from box_sdk_gen.schemas.folder_full import FolderFull

from box_sdk_gen.schemas.web_link import WebLink

from box_sdk_gen.schemas.recent_item_resource import RecentItemResource

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class RecentItemInteractionTypeField(str, Enum):
    ITEM_PREVIEW = 'item_preview'
    ITEM_UPLOAD = 'item_upload'
    ITEM_COMMENT = 'item_comment'
    ITEM_OPEN = 'item_open'
    ITEM_MODIFY = 'item_modify'


class RecentItem(BaseObject):
    def __init__(
        self,
        *,
        type: Optional[str] = None,
        item: Optional[RecentItemResource] = None,
        interaction_type: Optional[RecentItemInteractionTypeField] = None,
        interacted_at: Optional[DateTime] = None,
        interaction_shared_link: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The value will always be `recent_item`., defaults to None
                :type type: Optional[str], optional
                :param interaction_type: The most recent type of access the user performed on
        the item., defaults to None
                :type interaction_type: Optional[RecentItemInteractionTypeField], optional
                :param interacted_at: The time of the most recent interaction., defaults to None
                :type interacted_at: Optional[DateTime], optional
                :param interaction_shared_link: If the item was accessed through a shared link it will appear here,
        otherwise this will be null., defaults to None
                :type interaction_shared_link: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.item = item
        self.interaction_type = interaction_type
        self.interacted_at = interacted_at
        self.interaction_shared_link = interaction_shared_link



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.collaborator_variable import CollaboratorVariable

from box_sdk_gen.schemas.completion_rule_variable import CompletionRuleVariable

from box_sdk_gen.schemas.role_variable import RoleVariable

from box_sdk_gen.box.errors import BoxSDKError


class Outcome(BaseObject):
    def __init__(
        self,
        id: str,
        *,
        collaborators: Optional[CollaboratorVariable] = None,
        completion_rule: Optional[CompletionRuleVariable] = None,
        file_collaborator_role: Optional[RoleVariable] = None,
        task_collaborators: Optional[CollaboratorVariable] = None,
        role: Optional[RoleVariable] = None,
        **kwargs
    ):
        """
        :param id: ID of a specific outcome.
        :type id: str
        """
        super().__init__(**kwargs)
        self.id = id
        self.collaborators = collaborators
        self.completion_rule = completion_rule
        self.file_collaborator_role = file_collaborator_role
        self.task_collaborators = task_collaborators
        self.role = role



from enum import Enum

from typing import Optional

from box_sdk_gen.schemas.group_base import GroupBaseTypeField

from box_sdk_gen.schemas.group_base import GroupBase

from box_sdk_gen.box.errors import BoxSDKError


class GroupMiniGroupTypeField(str, Enum):
    MANAGED_GROUP = 'managed_group'
    ALL_USERS_GROUP = 'all_users_group'


class GroupMini(GroupBase):
    def __init__(
        self,
        id: str,
        *,
        name: Optional[str] = None,
        group_type: Optional[GroupMiniGroupTypeField] = None,
        type: GroupBaseTypeField = GroupBaseTypeField.GROUP,
        **kwargs
    ):
        """
        :param id: The unique identifier for this object.
        :type id: str
        :param name: The name of the group., defaults to None
        :type name: Optional[str], optional
        :param group_type: The type of the group., defaults to None
        :type group_type: Optional[GroupMiniGroupTypeField], optional
        :param type: The value will always be `group`., defaults to GroupBaseTypeField.GROUP
        :type type: GroupBaseTypeField, optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.name = name
        self.group_type = group_type



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.user import User

from box_sdk_gen.schemas.event_source import EventSource

from box_sdk_gen.schemas.file import File

from box_sdk_gen.schemas.folder import Folder

from box_sdk_gen.schemas.app_item_event_source import AppItemEventSource

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.schemas.event_source_resource import EventSourceResource

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class EventEventTypeField(str, Enum):
    ACCESS_GRANTED = 'ACCESS_GRANTED'
    ACCESS_REVOKED = 'ACCESS_REVOKED'
    ADD_DEVICE_ASSOCIATION = 'ADD_DEVICE_ASSOCIATION'
    ADD_LOGIN_ACTIVITY_DEVICE = 'ADD_LOGIN_ACTIVITY_DEVICE'
    ADMIN_LOGIN = 'ADMIN_LOGIN'
    APPLICATION_CREATED = 'APPLICATION_CREATED'
    APPLICATION_PUBLIC_KEY_ADDED = 'APPLICATION_PUBLIC_KEY_ADDED'
    APPLICATION_PUBLIC_KEY_DELETED = 'APPLICATION_PUBLIC_KEY_DELETED'
    CHANGE_ADMIN_ROLE = 'CHANGE_ADMIN_ROLE'
    CHANGE_FOLDER_PERMISSION = 'CHANGE_FOLDER_PERMISSION'
    COLLABORATION_ACCEPT = 'COLLABORATION_ACCEPT'
    COLLABORATION_EXPIRATION = 'COLLABORATION_EXPIRATION'
    COLLABORATION_INVITE = 'COLLABORATION_INVITE'
    COLLABORATION_REMOVE = 'COLLABORATION_REMOVE'
    COLLABORATION_ROLE_CHANGE = 'COLLABORATION_ROLE_CHANGE'
    COLLAB_ADD_COLLABORATOR = 'COLLAB_ADD_COLLABORATOR'
    COLLAB_INVITE_COLLABORATOR = 'COLLAB_INVITE_COLLABORATOR'
    COLLAB_REMOVE_COLLABORATOR = 'COLLAB_REMOVE_COLLABORATOR'
    COLLAB_ROLE_CHANGE = 'COLLAB_ROLE_CHANGE'
    COMMENT_CREATE = 'COMMENT_CREATE'
    COMMENT_DELETE = 'COMMENT_DELETE'
    CONTENT_ACCESS = 'CONTENT_ACCESS'
    CONTENT_WORKFLOW_ABNORMAL_DOWNLOAD_ACTIVITY = (
        'CONTENT_WORKFLOW_ABNORMAL_DOWNLOAD_ACTIVITY'
    )
    CONTENT_WORKFLOW_AUTOMATION_ADD = 'CONTENT_WORKFLOW_AUTOMATION_ADD'
    CONTENT_WORKFLOW_AUTOMATION_DELETE = 'CONTENT_WORKFLOW_AUTOMATION_DELETE'
    CONTENT_WORKFLOW_POLICY_ADD = 'CONTENT_WORKFLOW_POLICY_ADD'
    CONTENT_WORKFLOW_SHARING_POLICY_VIOLATION = (
        'CONTENT_WORKFLOW_SHARING_POLICY_VIOLATION'
    )
    CONTENT_WORKFLOW_UPLOAD_POLICY_VIOLATION = (
        'CONTENT_WORKFLOW_UPLOAD_POLICY_VIOLATION'
    )
    COPY = 'COPY'
    DATA_RETENTION_CREATE_RETENTION = 'DATA_RETENTION_CREATE_RETENTION'
    DATA_RETENTION_REMOVE_RETENTION = 'DATA_RETENTION_REMOVE_RETENTION'
    DELETE = 'DELETE'
    DELETE_USER = 'DELETE_USER'
    DEVICE_TRUST_CHECK_FAILED = 'DEVICE_TRUST_CHECK_FAILED'
    DOWNLOAD = 'DOWNLOAD'
    EDIT = 'EDIT'
    EDIT_USER = 'EDIT_USER'
    EDR_CROWDSTRIKE_DEVICE_DETECTED = 'EDR_CROWDSTRIKE_DEVICE_DETECTED'
    EDR_CROWDSTRIKE_NO_BOX_TOOLS = 'EDR_CROWDSTRIKE_NO_BOX_TOOLS'
    EDR_CROWDSTRIKE_BOX_TOOLS_OUTDATED = 'EDR_CROWDSTRIKE_BOX_TOOLS_OUTDATED'
    EDR_CROWDSTRIKE_DRIVE_OUTDATED = 'EDR_CROWDSTRIKE_DRIVE_OUTDATED'
    EDR_CROWDSTRIKE_ACCESS_ALLOWED_NO_CROWDSTRIKE_DEVICE = (
        'EDR_CROWDSTRIKE_ACCESS_ALLOWED_NO_CROWDSTRIKE_DEVICE'
    )
    EDR_CROWDSTRIKE_ACCESS_REVOKED = 'EDR_CROWDSTRIKE_ACCESS_REVOKED'
    EMAIL_ALIAS_CONFIRM = 'EMAIL_ALIAS_CONFIRM'
    EMAIL_ALIAS_REMOVE = 'EMAIL_ALIAS_REMOVE'
    ENABLE_TWO_FACTOR_AUTH = 'ENABLE_TWO_FACTOR_AUTH'
    ENTERPRISE_APP_AUTHORIZATION_UPDATE = 'ENTERPRISE_APP_AUTHORIZATION_UPDATE'
    FAILED_LOGIN = 'FAILED_LOGIN'
    FILE_MARKED_MALICIOUS = 'FILE_MARKED_MALICIOUS'
    FILE_WATERMARKED_DOWNLOAD = 'FILE_WATERMARKED_DOWNLOAD'
    GROUP_ADD_ITEM = 'GROUP_ADD_ITEM'
    GROUP_ADD_USER = 'GROUP_ADD_USER'
    GROUP_CREATION = 'GROUP_CREATION'
    GROUP_DELETION = 'GROUP_DELETION'
    GROUP_EDITED = 'GROUP_EDITED'
    GROUP_REMOVE_ITEM = 'GROUP_REMOVE_ITEM'
    GROUP_REMOVE_USER = 'GROUP_REMOVE_USER'
    ITEM_COPY = 'ITEM_COPY'
    ITEM_CREATE = 'ITEM_CREATE'
    ITEM_DOWNLOAD = 'ITEM_DOWNLOAD'
    ITEM_EMAIL_SEND = 'ITEM_EMAIL_SEND'
    ITEM_MAKE_CURRENT_VERSION = 'ITEM_MAKE_CURRENT_VERSION'
    ITEM_MODIFY = 'ITEM_MODIFY'
    ITEM_MOVE = 'ITEM_MOVE'
    ITEM_OPEN = 'ITEM_OPEN'
    ITEM_PREVIEW = 'ITEM_PREVIEW'
    ITEM_RENAME = 'ITEM_RENAME'
    ITEM_SHARED = 'ITEM_SHARED'
    ITEM_SHARED_CREATE = 'ITEM_SHARED_CREATE'
    ITEM_SHARED_UNSHARE = 'ITEM_SHARED_UNSHARE'
    ITEM_SHARED_UPDATE = 'ITEM_SHARED_UPDATE'
    ITEM_SYNC = 'ITEM_SYNC'
    ITEM_TRASH = 'ITEM_TRASH'
    ITEM_UNDELETE_VIA_TRASH = 'ITEM_UNDELETE_VIA_TRASH'
    ITEM_UNSYNC = 'ITEM_UNSYNC'
    ITEM_UPLOAD = 'ITEM_UPLOAD'
    LEGAL_HOLD_ASSIGNMENT_CREATE = 'LEGAL_HOLD_ASSIGNMENT_CREATE'
    LEGAL_HOLD_ASSIGNMENT_DELETE = 'LEGAL_HOLD_ASSIGNMENT_DELETE'
    LEGAL_HOLD_POLICY_CREATE = 'LEGAL_HOLD_POLICY_CREATE'
    LEGAL_HOLD_POLICY_DELETE = 'LEGAL_HOLD_POLICY_DELETE'
    LEGAL_HOLD_POLICY_UPDATE = 'LEGAL_HOLD_POLICY_UPDATE'
    LOCK = 'LOCK'
    LOCK_CREATE = 'LOCK_CREATE'
    LOCK_DESTROY = 'LOCK_DESTROY'
    LOGIN = 'LOGIN'
    MASTER_INVITE_ACCEPT = 'MASTER_INVITE_ACCEPT'
    MASTER_INVITE_REJECT = 'MASTER_INVITE_REJECT'
    METADATA_INSTANCE_CREATE = 'METADATA_INSTANCE_CREATE'
    METADATA_INSTANCE_DELETE = 'METADATA_INSTANCE_DELETE'
    METADATA_INSTANCE_UPDATE = 'METADATA_INSTANCE_UPDATE'
    METADATA_TEMPLATE_CREATE = 'METADATA_TEMPLATE_CREATE'
    METADATA_TEMPLATE_DELETE = 'METADATA_TEMPLATE_DELETE'
    METADATA_TEMPLATE_UPDATE = 'METADATA_TEMPLATE_UPDATE'
    MOVE = 'MOVE'
    NEW_USER = 'NEW_USER'
    PREVIEW = 'PREVIEW'
    REMOVE_DEVICE_ASSOCIATION = 'REMOVE_DEVICE_ASSOCIATION'
    REMOVE_LOGIN_ACTIVITY_DEVICE = 'REMOVE_LOGIN_ACTIVITY_DEVICE'
    RENAME = 'RENAME'
    RETENTION_POLICY_ASSIGNMENT_ADD = 'RETENTION_POLICY_ASSIGNMENT_ADD'
    SHARE = 'SHARE'
    SHARED_LINK_SEND = 'SHARED_LINK_SEND'
    SHARE_EXPIRATION = 'SHARE_EXPIRATION'
    SHIELD_ALERT = 'SHIELD_ALERT'
    SHIELD_EXTERNAL_COLLAB_ACCESS_BLOCKED = 'SHIELD_EXTERNAL_COLLAB_ACCESS_BLOCKED'
    SHIELD_EXTERNAL_COLLAB_ACCESS_BLOCKED_MISSING_JUSTIFICATION = (
        'SHIELD_EXTERNAL_COLLAB_ACCESS_BLOCKED_MISSING_JUSTIFICATION'
    )
    SHIELD_EXTERNAL_COLLAB_INVITE_BLOCKED = 'SHIELD_EXTERNAL_COLLAB_INVITE_BLOCKED'
    SHIELD_EXTERNAL_COLLAB_INVITE_BLOCKED_MISSING_JUSTIFICATION = (
        'SHIELD_EXTERNAL_COLLAB_INVITE_BLOCKED_MISSING_JUSTIFICATION'
    )
    SHIELD_JUSTIFICATION_APPROVAL = 'SHIELD_JUSTIFICATION_APPROVAL'
    SHIELD_SHARED_LINK_ACCESS_BLOCKED = 'SHIELD_SHARED_LINK_ACCESS_BLOCKED'
    SHIELD_SHARED_LINK_STATUS_RESTRICTED_ON_CREATE = (
        'SHIELD_SHARED_LINK_STATUS_RESTRICTED_ON_CREATE'
    )
    SHIELD_SHARED_LINK_STATUS_RESTRICTED_ON_UPDATE = (
        'SHIELD_SHARED_LINK_STATUS_RESTRICTED_ON_UPDATE'
    )
    SIGN_DOCUMENT_ASSIGNED = 'SIGN_DOCUMENT_ASSIGNED'
    SIGN_DOCUMENT_CANCELLED = 'SIGN_DOCUMENT_CANCELLED'
    SIGN_DOCUMENT_COMPLETED = 'SIGN_DOCUMENT_COMPLETED'
    SIGN_DOCUMENT_CONVERTED = 'SIGN_DOCUMENT_CONVERTED'
    SIGN_DOCUMENT_CREATED = 'SIGN_DOCUMENT_CREATED'
    SIGN_DOCUMENT_DECLINED = 'SIGN_DOCUMENT_DECLINED'
    SIGN_DOCUMENT_EXPIRED = 'SIGN_DOCUMENT_EXPIRED'
    SIGN_DOCUMENT_SIGNED = 'SIGN_DOCUMENT_SIGNED'
    SIGN_DOCUMENT_VIEWED_BY_SIGNED = 'SIGN_DOCUMENT_VIEWED_BY_SIGNED'
    SIGNER_DOWNLOADED = 'SIGNER_DOWNLOADED'
    SIGNER_FORWARDED = 'SIGNER_FORWARDED'
    STORAGE_EXPIRATION = 'STORAGE_EXPIRATION'
    TAG_ITEM_CREATE = 'TAG_ITEM_CREATE'
    TASK_ASSIGNMENT_CREATE = 'TASK_ASSIGNMENT_CREATE'
    TASK_ASSIGNMENT_DELETE = 'TASK_ASSIGNMENT_DELETE'
    TASK_ASSIGNMENT_UPDATE = 'TASK_ASSIGNMENT_UPDATE'
    TASK_CREATE = 'TASK_CREATE'
    TASK_UPDATE = 'TASK_UPDATE'
    TERMS_OF_SERVICE_ACCEPT = 'TERMS_OF_SERVICE_ACCEPT'
    TERMS_OF_SERVICE_REJECT = 'TERMS_OF_SERVICE_REJECT'
    UNDELETE = 'UNDELETE'
    UNLOCK = 'UNLOCK'
    UNSHARE = 'UNSHARE'
    UPDATE_COLLABORATION_EXPIRATION = 'UPDATE_COLLABORATION_EXPIRATION'
    UPDATE_SHARE_EXPIRATION = 'UPDATE_SHARE_EXPIRATION'
    UPLOAD = 'UPLOAD'
    USER_AUTHENTICATE_OAUTH2_ACCESS_TOKEN_CREATE = (
        'USER_AUTHENTICATE_OAUTH2_ACCESS_TOKEN_CREATE'
    )
    WATERMARK_LABEL_CREATE = 'WATERMARK_LABEL_CREATE'
    WATERMARK_LABEL_DELETE = 'WATERMARK_LABEL_DELETE'


class Event(BaseObject):
    def __init__(
        self,
        *,
        type: Optional[str] = None,
        created_at: Optional[DateTime] = None,
        recorded_at: Optional[DateTime] = None,
        event_id: Optional[str] = None,
        created_by: Optional[UserMini] = None,
        event_type: Optional[EventEventTypeField] = None,
        session_id: Optional[str] = None,
        source: Optional[EventSourceResource] = None,
        additional_details: Optional[Dict] = None,
        **kwargs
    ):
        """
                :param type: The value will always be `event`., defaults to None
                :type type: Optional[str], optional
                :param created_at: When the event object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param recorded_at: When the event object was recorded in database., defaults to None
                :type recorded_at: Optional[DateTime], optional
                :param event_id: The ID of the event object. You can use this to detect duplicate events., defaults to None
                :type event_id: Optional[str], optional
                :param session_id: The session of the user that performed the action. Not all events will
        populate this attribute., defaults to None
                :type session_id: Optional[str], optional
                :param additional_details: This object provides additional information about the event if available.

        This can include how a user performed an event as well as additional
        information to correlate an event to external KeySafe logs. Not all events
        have an `additional_details` object.  This object is only available in the
        Enterprise Events., defaults to None
                :type additional_details: Optional[Dict], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.created_at = created_at
        self.recorded_at = recorded_at
        self.event_id = event_id
        self.created_by = created_by
        self.event_type = event_type
        self.session_id = session_id
        self.source = source
        self.additional_details = additional_details



from typing import Optional

from box_sdk_gen.schemas.legal_hold_policy_assignment_base import (
    LegalHoldPolicyAssignmentBaseTypeField,
)

from box_sdk_gen.schemas.file import File

from box_sdk_gen.schemas.folder import Folder

from box_sdk_gen.schemas.web_link import WebLink

from box_sdk_gen.schemas.legal_hold_policy_assignment_base import (
    LegalHoldPolicyAssignmentBase,
)

from box_sdk_gen.schemas.legal_hold_policy_mini import LegalHoldPolicyMini

from box_sdk_gen.schemas.legal_hold_policy_assigned_item import (
    LegalHoldPolicyAssignedItem,
)

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class LegalHoldPolicyAssignment(LegalHoldPolicyAssignmentBase):
    def __init__(
        self,
        *,
        legal_hold_policy: Optional[LegalHoldPolicyMini] = None,
        assigned_to: Optional[LegalHoldPolicyAssignedItem] = None,
        assigned_by: Optional[UserMini] = None,
        assigned_at: Optional[DateTime] = None,
        deleted_at: Optional[DateTime] = None,
        id: Optional[str] = None,
        type: Optional[LegalHoldPolicyAssignmentBaseTypeField] = None,
        **kwargs
    ):
        """
                :param assigned_at: When the legal hold policy assignment object was
        created., defaults to None
                :type assigned_at: Optional[DateTime], optional
                :param deleted_at: When the assignment release request was sent.
        (Because it can take time for an assignment to fully
        delete, this isn't quite the same time that the
        assignment is fully deleted). If null, Assignment
        was not deleted., defaults to None
                :type deleted_at: Optional[DateTime], optional
                :param id: The unique identifier for this legal hold assignment., defaults to None
                :type id: Optional[str], optional
                :param type: The value will always be `legal_hold_policy_assignment`., defaults to None
                :type type: Optional[LegalHoldPolicyAssignmentBaseTypeField], optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.legal_hold_policy = legal_hold_policy
        self.assigned_to = assigned_to
        self.assigned_by = assigned_by
        self.assigned_at = assigned_at
        self.deleted_at = deleted_at



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class UserAvatarPicUrlsField(BaseObject):
    def __init__(
        self,
        *,
        small: Optional[str] = None,
        large: Optional[str] = None,
        preview: Optional[str] = None,
        **kwargs
    ):
        """
        :param small: The location of a small-sized avatar., defaults to None
        :type small: Optional[str], optional
        :param large: The location of a large-sized avatar., defaults to None
        :type large: Optional[str], optional
        :param preview: The location of the avatar preview., defaults to None
        :type preview: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.small = small
        self.large = large
        self.preview = preview


class UserAvatar(BaseObject):
    def __init__(self, *, pic_urls: Optional[UserAvatarPicUrlsField] = None, **kwargs):
        """
        :param pic_urls: Represents an object with user avatar URLs., defaults to None
        :type pic_urls: Optional[UserAvatarPicUrlsField], optional
        """
        super().__init__(**kwargs)
        self.pic_urls = pic_urls



from typing import Union

from box_sdk_gen.schemas.file_base import FileBase

from box_sdk_gen.schemas.folder_base import FolderBase

from box_sdk_gen.schemas.web_link_base import WebLinkBase

from box_sdk_gen.box.errors import BoxSDKError

AppItemAssociatedItem = Union[FileBase, FolderBase, WebLinkBase]



from typing import Dict

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.ai_agent_info import AiAgentInfo

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class AiExtractStructuredResponse(BaseObject):
    def __init__(
        self,
        answer: Dict,
        created_at: DateTime,
        *,
        completion_reason: Optional[str] = None,
        confidence_score: Optional[Dict] = None,
        ai_agent_info: Optional[AiAgentInfo] = None,
        **kwargs
    ):
        """
        :param created_at: The ISO date formatted timestamp of when the answer to the prompt was created.
        :type created_at: DateTime
        :param completion_reason: The reason the response finishes., defaults to None
        :type completion_reason: Optional[str], optional
        :param confidence_score: The confidence score levels and numeric values for each extracted field as a JSON dictionary. This can be empty if no field could be extracted., defaults to None
        :type confidence_score: Optional[Dict], optional
        """
        super().__init__(**kwargs)
        self.answer = answer
        self.created_at = created_at
        self.completion_reason = completion_reason
        self.confidence_score = confidence_score
        self.ai_agent_info = ai_agent_info



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from typing import Dict

from box_sdk_gen.schemas.client_error import ClientErrorTypeField

from box_sdk_gen.schemas.client_error import ClientErrorCodeField

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.file_conflict import FileConflict

from box_sdk_gen.box.errors import BoxSDKError


class ConflictErrorContextInfoField(BaseObject):
    def __init__(self, *, conflicts: Optional[List[FileConflict]] = None, **kwargs):
        """
        :param conflicts: A list of the file conflicts that caused this error., defaults to None
        :type conflicts: Optional[List[FileConflict]], optional
        """
        super().__init__(**kwargs)
        self.conflicts = conflicts


class ConflictError(ClientError):
    def __init__(
        self,
        *,
        type: Optional[ClientErrorTypeField] = None,
        status: Optional[int] = None,
        code: Optional[ClientErrorCodeField] = None,
        message: Optional[str] = None,
        context_info: Optional[Dict] = None,
        help_url: Optional[str] = None,
        request_id: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The value will always be `error`., defaults to None
                :type type: Optional[ClientErrorTypeField], optional
                :param status: The HTTP status of the response., defaults to None
                :type status: Optional[int], optional
                :param code: A Box-specific error code., defaults to None
                :type code: Optional[ClientErrorCodeField], optional
                :param message: A short message describing the error., defaults to None
                :type message: Optional[str], optional
                :param context_info: A free-form object that contains additional context
        about the error. The possible fields are defined on
        a per-endpoint basis. `message` is only one example., defaults to None
                :type context_info: Optional[Dict], optional
                :param help_url: A URL that links to more information about why this error occurred., defaults to None
                :type help_url: Optional[str], optional
                :param request_id: A unique identifier for this response, which can be used
        when contacting Box support., defaults to None
                :type request_id: Optional[str], optional
        """
        super().__init__(
            type=type,
            status=status,
            code=code,
            message=message,
            context_info=context_info,
            help_url=help_url,
            request_id=request_id,
            **kwargs
        )



from typing import Union

from box_sdk_gen.schemas.ai_llm_endpoint_params_open_ai import AiLlmEndpointParamsOpenAi

from box_sdk_gen.schemas.ai_llm_endpoint_params_google import AiLlmEndpointParamsGoogle

from box_sdk_gen.schemas.ai_llm_endpoint_params_aws import AiLlmEndpointParamsAws

from box_sdk_gen.schemas.ai_llm_endpoint_params_ibm import AiLlmEndpointParamsIbm

from box_sdk_gen.box.errors import BoxSDKError

AiLlmEndpointParams = Union[
    AiLlmEndpointParamsOpenAi,
    AiLlmEndpointParamsGoogle,
    AiLlmEndpointParamsAws,
    AiLlmEndpointParamsIbm,
]



from box_sdk_gen.box import *

from box_sdk_gen.serialization import *

from box_sdk_gen.internal import *

from box_sdk_gen.networking import *

from box_sdk_gen.schemas import *

from box_sdk_gen.parameters import *

from box_sdk_gen.managers import *

from box_sdk_gen.client import *
